==> apache-shenyu-incubating-2.4.1-src.zip: apache-shenyu-incubating-2.4.1-src/shenyu-admin/src/main/java/org/apache/shenyu/admin/mapper/MetaDataMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.mapper;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.shenyu.admin.model.entity.MetaDataDO;
import org.apache.shenyu.admin.model.query.MetaDataQuery;

import java.util.List;

/**
 * The interface Meta data mapper.
 */
@Mapper
public interface MetaDataMapper {

    /**
     * Select by id meta data do.
     *
     * @param id the id
     * @return the meta data do
     */
    MetaDataDO selectById(String id);

    /**
     * Find all list.
     *
     * @return the list
     */
    List<MetaDataDO> findAll();

    /**
     * Find by path meta data do.
     *
     * @param path the path
     * @return the meta data do
     */
    MetaDataDO findByPath(String path);

    /**
     * Find by service name and method meta data do.
     *
     * @param serviceName the service name
     * @param methodName      the methodName
     * @return the meta data do
     */
    MetaDataDO findByServiceNameAndMethod(@Param("serviceName") String serviceName, @Param("methodName") String methodName);

    /**
     * Select by query list.
     *
     * @param metaDataQuery the meta data query
     * @return the list
     */
    List<MetaDataDO> selectByQuery(MetaDataQuery metaDataQuery);

    /**
     * Select all list.
     *
     * @return the list
     */
    List<MetaDataDO> selectAll();

    /**
     * Count by query integer.
     *
     * @param metaDataQuery the meta data query
     * @return the integer
     */
    Integer countByQuery(MetaDataQuery metaDataQuery);

    /**
     * Insert int.
     *
     * @param metaDataDO the meta data do
     * @return the int
     */
    int insert(MetaDataDO metaDataDO);

    /**
     * Update int.
     *
     * @param metaDataDO the meta data do
     * @return the int
     */
    int update(MetaDataDO metaDataDO);

    /**
     * Update enable int.
     *
     * @param metaDataDO the meta data do
     * @return the int
     */
    int updateEnable(MetaDataDO metaDataDO);

    /**
     * Delete int.
     *
     * @param id the id
     * @return the int
     */
    int delete(String id);
}

==> apache-shenyu-incubating-2.4.2-src.zip: apache-shenyu-incubating-2.4.2-src/shenyu-admin/src/main/java/org/apache/shenyu/admin/mapper/MetaDataMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.mapper;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.shenyu.admin.model.entity.MetaDataDO;
import org.apache.shenyu.admin.model.query.MetaDataQuery;

import java.util.List;
import java.util.Set;

/**
 * The interface Meta data mapper.
 */
@Mapper
public interface MetaDataMapper {

    /**
     * Select by id meta data do.
     *
     * @param id the id
     * @return the meta data do
     */
    MetaDataDO selectById(String id);

    /**
     * Select a list of MetaDataDOs by idList.
     * @param idSet a set of ids
     * @return a list of MetaDataDOs
     */
    List<MetaDataDO> selectByIdSet(@Param("idSet") Set<String> idSet);

    /**
     * Find all list.
     *
     * @return the list
     */
    List<MetaDataDO> findAll();

    /**
     * Find by path meta data do.
     *
     * @param path the path
     * @return the meta data do
     */
    MetaDataDO findByPath(String path);

    /**
     * Find by service name and method meta data do.
     *
     * @param serviceName the service name
     * @param methodName      the methodName
     * @return the meta data do
     */
    MetaDataDO findByServiceNameAndMethod(@Param("serviceName") String serviceName, @Param("methodName") String methodName);

    /**
     * Select by query list.
     *
     * @param metaDataQuery the meta data query
     * @return the list
     */
    List<MetaDataDO> selectByQuery(MetaDataQuery metaDataQuery);

    /**
     * Select all list.
     *
     * @return the list
     */
    List<MetaDataDO> selectAll();

    /**
     * Count by query integer.
     *
     * @param metaDataQuery the meta data query
     * @return the integer
     */
    Integer countByQuery(MetaDataQuery metaDataQuery);

    /**
     * Insert int.
     *
     * @param metaDataDO the meta data do
     * @return the int
     */
    int insert(MetaDataDO metaDataDO);

    /**
     * Update int.
     *
     * @param metaDataDO the meta data do
     * @return the int
     */
    int update(MetaDataDO metaDataDO);

    /**
     * Update enable int.
     *
     * @param metaDataDO the meta data do
     * @return the int
     */
    int updateEnable(MetaDataDO metaDataDO);

    /**
     * update enable batch.
     *
     * @param idSet the ids
     * @param enabled the status
     * @return the count
     */
    int updateEnableBatch(@Param("idSet") Set<String> idSet, @Param("enabled") Boolean enabled);

    /**
     * Delete int.
     *
     * @param id the id
     * @return the int
     */
    int delete(String id);

    /**
     * batch delete by a set of ids.
     * @param idSet a set of ids
     * @return the count of deleted
     */
    int deleteByIdSet(@Param("idSet") Set<String> idSet);
}
